<!-- 业务弹层表格组件，适用在病害选择病害类别时，选择了边坡类型后选择具体哪所桥梁 -->
<template>
    <el-dialog
        fullscreen
        title="选择边坡"
        :visible.sync="dialogVisible"
        width="30%"
        :before-close="handleClose"
    >
        <div class="contianer">
            <div class="container_search">
                <el-form ref="searchForm" :model="searchForm" class="searchTop">
                    <CascaderCompany
                        :companyIds.sync="searchForm.companyIds"
                        :roadSegmentId.sync="searchForm.roadSegmentId"
                        :placeholder="'请选择公司名称'"
                    />
                    <el-select
                        v-model="searchForm.roadSegmentId"
                        placeholder="请选择路段"
                        clearable
                    >
                        <el-option
                            v-for="item in roadList"
                            :key="item.id"
                            :label="item.name"
                            :value="item.id"
                        >
                        </el-option>
                    </el-select>
                    <router-info-selectorcopy
                        v-model="searchForm.routeName"
                        :value="searchForm.routeName"
                        @changed="routechanged"
                        clearable
                        @clear="clear"
                    />
                    <dict-select
                        dictCode="qlfx"
                        :hasDefaultOption="true"
                        clearable
                        v-model="searchForm.direction"
                        placeholder="请选择方向"
                    />
                    <dict-select
                        dictCode="bplx"
                        :hasDefaultOption="true"
                        clearable
                        v-model="searchForm.isHighRisk"
                        placeholder="请选择边坡类型"
                    />
                    <el-select
                        v-model="searchForm.isRamp"
                        placeholder="请选择是否匝道物"
                        clearable
                    >
                        <el-option
                            v-for="item in rampOptions"
                            :key="item.value"
                            :label="item.label"
                            :value="item.value"
                        >
                        </el-option>
                    </el-select>
                    <el-button size="small" @click="findinfo" type="primary">
                        查询
                    </el-button>
                </el-form>
            </div>
            <div class="contianer_table">
                <ht-table
                    @load="loadData"
                    :data="data"
                    :pageResult="pageResult"
                    :selection="false"
                    :selectable="false"
                    :show-export="false"
                    :show-custom-column="false"
                    ref="dialogHtTable"
                    highlightCurrentRow
                    @row-click="handleRowClick"
                    :default-sorter="[{direction: 'DESC', property: 'id_'}]"
                >
                    <template>
                        <ht-table-column width="50">
                            <template v-slot="{row}">
                                <el-radio-group v-model="radioCurrent">
                                    <el-radio :label="row.id" />
                                </el-radio-group>
                            </template>
                        </ht-table-column>
                        <ht-table-column
                            prop="number"
                            label="编号"
                            :sortable="true"
                            :show-overflow-tooltip="true"
                        >
                        </ht-table-column>
                        <ht-table-column
                            prop="roadSegmentName"
                            label="所在路段"
                            :show-overflow-tooltip="true"
                        >
                        </ht-table-column>

                        <ht-table-column
                            prop="direction"
                            label="方向"
                            :show-overflow-tooltip="true"
                            :filters="getDictData('qlfx')"
                        >
                            <template v-slot="{row}">
                                <div>{{ getDictName('qlfx', row.direction) }}</div>
                            </template>
                        </ht-table-column>
                        <ht-table-column
                            prop="protectType"
                            label="保护类型"
                            :sortable="true"
                            :show-overflow-tooltip="true"
                        >
                        </ht-table-column>
                        <ht-table-column
                            prop="protectMaterial"
                            label="防护材料"
                            :sortable="true"
                            :show-overflow-tooltip="true"
                        >
                        </ht-table-column>
                        <ht-table-column
                            prop="height"
                            label="高度"
                            :sortable="true"
                            :show-overflow-tooltip="true"
                        >
                        </ht-table-column>
                        <ht-table-column
                            prop="length"
                            label="长度"
                            :sortable="true"
                            :show-overflow-tooltip="true"
                        >
                        </ht-table-column>

                        <ht-table-column
                            prop="isHighRisk"
                            label="边坡类型"
                            :show-overflow-tooltip="true"
                            :filters="getDictData('bplx')"
                        >
                            <template v-slot="{row}">
                                <div>{{ getDictName('bplx', row.isHighRisk) }}</div>
                            </template>
                        </ht-table-column>
                        <ht-table-column
                            prop="isRamp"
                            label="是否斜坡"
                            :show-overflow-tooltip="true"
                            :filters="[
                                {text: '否', value: 0},
                                {text: '是', value: 1},
                            ]"
                        >
                            <template v-slot="{row}">
                                <el-tag type="danger" v-if="row.isRamp == '0'">否</el-tag>
                                <el-tag type="success" v-if="row.isRamp == '1'">
                                    是
                                </el-tag>
                            </template>
                        </ht-table-column>
                    </template>
                </ht-table>
            </div>
        </div>
        <span slot="footer" class="dialog-footer">
            <el-button @click="dialogVisible = false">取 消</el-button>
            <el-button type="primary" @click="submit">确 定</el-button>
        </span>
    </el-dialog>
</template>

<script>
import basicData from '@/api/basicData.js'
import CascaderCompany from '@/components/selector/CascaderCompany.vue'
import routerInfoSelectorcopy from '@/components/selector/routerInfoSelectorcopy.vue'
export default {
    name: 'DialogSelectSideSlope',
    components: {
        CascaderCompany,
        routerInfoSelectorcopy,
    },
    data() {
        return {
            data: [],
            dialogVisible: false,
            searchForm: {},
            roadList: [],
            radioCurrent: '',
            pageResult: {
                page: 1,
                pageSize: 20,
                total: 0,
            },
            current: null,
            rampOptions: [
                {value: '0', label: '否'},
                {value: '1', label: '是'},
            ],
        }
    },
    created() {
        this.getRoadList()
    },
    mounted() {},
    methods: {
        submit() {
            this.dialogVisible = false
            this.$emit('handleSubmit', this.current)
        },
        open() {
            this.dialogVisible = true
        },
        handleClose() {
            this.dialogVisible = false
        },
        handleRowClick(row) {
            this.radioCurrent = row.id
            this.current = row
        },
        getRoadList() {
            basicData.getRoadManagement().then((res) => {
                let data = res.rows
                this.roadList = data
            })
        },
        uniqueFunc(arr, uniId) {
            const res = new Map()
            return arr.filter((item) => !res.has(item[uniId]) && res.set(item[uniId], 1))
        },
        findinfo() {
            let query = []
            let params = {routeId: this.searchForm.routeId}
            let search = {
                company_id_: this.searchForm.companyIds,
                road_segment_id_: this.searchForm.roadSegmentId,
                direction: this.searchForm.direction,
                is_high_risk_: this.searchForm.isHighRisk,
                is_ramp_: this.searchForm.isRamp,
            }
            for (let i in search) {
                if (search[i]) {
                    if (i == 'company_id_') {
                        query.push({
                            group: 'companyIds',
                            operation: 'IN',
                            parentGroup: '',
                            property: 'COMPANY_ID_',
                            relation: 'AND',
                            value: search[i],
                        })
                    } else {
                        query.push({
                            group: 'advance',
                            operation: 'LIKE',
                            property: i,
                            relation: 'AND',
                            value: search[i],
                        })
                    }
                }
            }
            query = this.uniqueFunc(query, 'property')
            let data = {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    showTotal: true,
                },
                querys: query,
                params: params,
            }
            basicData.getSideSlopeManagement(data).then((res) => {
                let response = res
                this.data = response.rows
                this.pageResult = {
                    page: response.page,
                    pageSize: response.pageSize,
                    total: response.total,
                }
            })
        },
        //路线信息赋值
        routechanged(data) {
            this.searchForm.routeName = data.name
            this.searchForm.routeId = data.id
        },
        clear() {
            this.searchForm.name = ''
            this.searchForm.routeId = ''
        },
        loadData(param, cb) {
            basicData
                .getSideSlopeManagement(param)
                .then(
                    (resp) => {
                        let response = resp
                        this.data = response.rows
                        this.pageResult = {
                            page: response.page,
                            pageSize: response.pageSize,
                            total: response.total,
                        }
                    },
                    (error) => {
                        reject(error)
                    }
                )
                .finally(() => {
                    if (cb) {
                        cb()
                    }
                })
        },
    },
}
</script>

<style lang="scss" scoped>
/deep/ .el-dialog.is-fullscreen {
    display: flex;
    flex-direction: column;
}
/deep/ .el-dialog__body {
    flex: 1;
}
/deep/ .el-form {
    height: 45px;
    line-height: 45px;
    padding-left: 10px;
    width: 100%;
}
/deep/ .el-select,
/deep/ .el-date-editor.el-input,
/deep/ .inputs {
    margin-left: 0;
    margin-bottom: 0;
}
/deep/ .ht-table-panel {
    height: 100% !important;
    background-color: #0d3959 !important;
}
.searchTop > div {
    max-width: 200px;
}
.contianer {
    height: 100%;
    display: flex;
    flex-direction: column;
    .container_search {
        display: flex;
        align-items: center;
    }
    .contianer_table {
        flex: 1;
    }
}
</style>
